@@ -1,36 +1,40 @@
+#include <QDir>
 #include <QFile>
+#include <QLineEdit>
 #include <QMessageBox>
+#include <QRegularExpression>
 #include <QTextStream>
 
 #include "choosedialog.h"
 #include "cmd.h"
+#include "common.h"
 #include "ui_choosedialog.h"
 
-chooseDialog::chooseDialog(QWidget *parent)
+ChooseDialog::ChooseDialog(QWidget *parent)
     : QDialog(parent),
-      ui(new Ui::chooseDialog)
+      ui(new Ui::ChooseDialog)
 {
     ui->setupUi(this);
     setup();
 }
 
-chooseDialog::~chooseDialog()
+ChooseDialog::~ChooseDialog()
 {
     delete ui;
 }
 
 // Setup various items first time program runs
-void chooseDialog::setup()
+void ChooseDialog::setup()
 {
     this->setWindowTitle(tr("MX Locale", "name of application"));
     buildLocaleList();
     ui->textSearch->setFocus();
-    connect(ui->textSearch, &QLineEdit::textChanged, this, &chooseDialog::textSearch_textChanged);
+    connect(ui->textSearch, &QLineEdit::textChanged, this, &ChooseDialog::textSearch_textChanged);
 }
 
-void chooseDialog::buildLocaleList()
+void ChooseDialog::buildLocaleList()
 {
-    QFile libFile("/usr/lib/mx-locale/locale.lib");
+    QFile libFile(QDir(Paths::mxLocaleLib).filePath("locale.lib"));
     QString locales = Cmd().getOut(R"(locale --all-locales)");
     QStringList availableLocales = locales.split(QRegularExpression(R"((\r\n)|(\n\r)|\r|\n)"), Qt::SkipEmptyParts)
                                        .filter(QRegularExpression(R"(\.(utf8|UTF-8)$)"))
@@ -64,7 +68,7 @@ void chooseDialog::buildLocaleList()
     }
 }
 
-QString chooseDialog::selection() const
+QString ChooseDialog::selection() const
 {
     if (ui->listWidgetAvailableLocales->currentRow() == -1) {
         return {};
@@ -74,7 +78,7 @@ QString chooseDialog::selection() const
     return selection;
 }
 
-void chooseDialog::textSearch_textChanged()
+void ChooseDialog::textSearch_textChanged()
 {
     QString searchText = ui->textSearch->text();
     for (int i = 0; i < ui->listWidgetAvailableLocales->count(); ++i) {
