@@ -25,5 +25,5 @@ signals:
 private:
     QString elevate;
     QString helper;
-    QString out_buffer;
+    QString outBuffer;
 };
